"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeReservationXShareSettingsXProjectMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    project_id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "project_id", b"project_id"]) -> None: ...

global___ComputeReservationXShareSettingsXProjectMap = ComputeReservationXShareSettingsXProjectMap

@typing_extensions.final
class ComputeReservationXShareSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_MAP_FIELD_NUMBER: builtins.int
    share_type: builtins.str
    @property
    def project_map(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeReservationXShareSettingsXProjectMap]: ...
    def __init__(
        self,
        *,
        share_type: builtins.str = ...,
        project_map: collections.abc.Iterable[global___ComputeReservationXShareSettingsXProjectMap] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_map", b"project_map", "share_type", b"share_type"]) -> None: ...

global___ComputeReservationXShareSettings = ComputeReservationXShareSettings

@typing_extensions.final
class ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_COUNT_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    accelerator_count: builtins.float
    accelerator_type: builtins.str
    def __init__(
        self,
        *,
        accelerator_count: builtins.float = ...,
        accelerator_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_count", b"accelerator_count", "accelerator_type", b"accelerator_type"]) -> None: ...

global___ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators = ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators

@typing_extensions.final
class ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    INTERFACE_FIELD_NUMBER: builtins.int
    disk_size_gb: builtins.float
    interface: builtins.str
    def __init__(
        self,
        *,
        disk_size_gb: builtins.float = ...,
        interface: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_size_gb", b"disk_size_gb", "interface", b"interface"]) -> None: ...

global___ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds = ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds

@typing_extensions.final
class ComputeReservationXSpecificReservationXInstanceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATORS_FIELD_NUMBER: builtins.int
    LOCAL_SSDS_FIELD_NUMBER: builtins.int
    machine_type: builtins.str
    min_cpu_platform: builtins.str
    @property
    def guest_accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators]: ...
    @property
    def local_ssds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds]: ...
    def __init__(
        self,
        *,
        machine_type: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        guest_accelerators: collections.abc.Iterable[global___ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators] | None = ...,
        local_ssds: collections.abc.Iterable[global___ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["guest_accelerators", b"guest_accelerators", "local_ssds", b"local_ssds", "machine_type", b"machine_type", "min_cpu_platform", b"min_cpu_platform"]) -> None: ...

global___ComputeReservationXSpecificReservationXInstanceProperties = ComputeReservationXSpecificReservationXInstanceProperties

@typing_extensions.final
class ComputeReservationXSpecificReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    IN_USE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_PROPERTIES_FIELD_NUMBER: builtins.int
    count: builtins.float
    in_use_count: builtins.float
    @property
    def instance_properties(self) -> global___ComputeReservationXSpecificReservationXInstanceProperties: ...
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        in_use_count: builtins.float = ...,
        instance_properties: global___ComputeReservationXSpecificReservationXInstanceProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instance_properties", b"instance_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "in_use_count", b"in_use_count", "instance_properties", b"instance_properties"]) -> None: ...

global___ComputeReservationXSpecificReservation = ComputeReservationXSpecificReservation

@typing_extensions.final
class ComputeReservationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeReservationXTimeouts = ComputeReservationXTimeouts

@typing_extensions.final
class ComputeReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMITMENT_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SPECIFIC_RESERVATION_REQUIRED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    SHARE_SETTINGS_FIELD_NUMBER: builtins.int
    SPECIFIC_RESERVATION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    commitment: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    specific_reservation_required: builtins.bool
    status: builtins.str
    zone: builtins.str
    @property
    def share_settings(self) -> global___ComputeReservationXShareSettings: ...
    @property
    def specific_reservation(self) -> global___ComputeReservationXSpecificReservation: ...
    @property
    def timeouts(self) -> global___ComputeReservationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        commitment: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        specific_reservation_required: builtins.bool = ...,
        status: builtins.str = ...,
        zone: builtins.str = ...,
        share_settings: global___ComputeReservationXShareSettings | None = ...,
        specific_reservation: global___ComputeReservationXSpecificReservation | None = ...,
        timeouts: global___ComputeReservationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "share_settings", b"share_settings", "specific_reservation", b"specific_reservation", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commitment", b"commitment", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "share_settings", b"share_settings", "specific_reservation", b"specific_reservation", "specific_reservation_required", b"specific_reservation_required", "status", b"status", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeReservation = ComputeReservation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudiotDeviceXCredentialsXPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORMAT_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    format: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        format: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["format", b"format", "key", b"key"]) -> None: ...

global___CloudiotDeviceXCredentialsXPublicKey = CloudiotDeviceXCredentialsXPublicKey

@typing_extensions.final
class CloudiotDeviceXCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    expiration_time: builtins.str
    @property
    def public_key(self) -> global___CloudiotDeviceXCredentialsXPublicKey: ...
    def __init__(
        self,
        *,
        expiration_time: builtins.str = ...,
        public_key: global___CloudiotDeviceXCredentialsXPublicKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["public_key", b"public_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "public_key", b"public_key"]) -> None: ...

global___CloudiotDeviceXCredentials = CloudiotDeviceXCredentials

@typing_extensions.final
class CloudiotDeviceXGatewayConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_AUTH_METHOD_FIELD_NUMBER: builtins.int
    GATEWAY_TYPE_FIELD_NUMBER: builtins.int
    LAST_ACCESSED_GATEWAY_ID_FIELD_NUMBER: builtins.int
    LAST_ACCESSED_GATEWAY_TIME_FIELD_NUMBER: builtins.int
    gateway_auth_method: builtins.str
    gateway_type: builtins.str
    last_accessed_gateway_id: builtins.str
    last_accessed_gateway_time: builtins.str
    def __init__(
        self,
        *,
        gateway_auth_method: builtins.str = ...,
        gateway_type: builtins.str = ...,
        last_accessed_gateway_id: builtins.str = ...,
        last_accessed_gateway_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gateway_auth_method", b"gateway_auth_method", "gateway_type", b"gateway_type", "last_accessed_gateway_id", b"last_accessed_gateway_id", "last_accessed_gateway_time", b"last_accessed_gateway_time"]) -> None: ...

global___CloudiotDeviceXGatewayConfig = CloudiotDeviceXGatewayConfig

@typing_extensions.final
class CloudiotDeviceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudiotDeviceXTimeouts = CloudiotDeviceXTimeouts

@typing_extensions.final
class CloudiotDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LastErrorStatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StateEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BLOCKED_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LAST_CONFIG_ACK_TIME_FIELD_NUMBER: builtins.int
    LAST_CONFIG_SEND_TIME_FIELD_NUMBER: builtins.int
    LAST_ERROR_STATUS_FIELD_NUMBER: builtins.int
    LAST_ERROR_TIME_FIELD_NUMBER: builtins.int
    LAST_EVENT_TIME_FIELD_NUMBER: builtins.int
    LAST_HEARTBEAT_TIME_FIELD_NUMBER: builtins.int
    LAST_STATE_TIME_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NUM_ID_FIELD_NUMBER: builtins.int
    REGISTRY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    GATEWAY_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    blocked: builtins.bool
    @property
    def config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    last_config_ack_time: builtins.str
    last_config_send_time: builtins.str
    @property
    def last_error_status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    last_error_time: builtins.str
    last_event_time: builtins.str
    last_heartbeat_time: builtins.str
    last_state_time: builtins.str
    log_level: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    num_id: builtins.str
    registry: builtins.str
    @property
    def state(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudiotDeviceXCredentials]: ...
    @property
    def gateway_config(self) -> global___CloudiotDeviceXGatewayConfig: ...
    @property
    def timeouts(self) -> global___CloudiotDeviceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        blocked: builtins.bool = ...,
        config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        last_config_ack_time: builtins.str = ...,
        last_config_send_time: builtins.str = ...,
        last_error_status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        last_error_time: builtins.str = ...,
        last_event_time: builtins.str = ...,
        last_heartbeat_time: builtins.str = ...,
        last_state_time: builtins.str = ...,
        log_level: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        num_id: builtins.str = ...,
        registry: builtins.str = ...,
        state: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        credentials: collections.abc.Iterable[global___CloudiotDeviceXCredentials] | None = ...,
        gateway_config: global___CloudiotDeviceXGatewayConfig | None = ...,
        timeouts: global___CloudiotDeviceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gateway_config", b"gateway_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blocked", b"blocked", "config", b"config", "credentials", b"credentials", "gateway_config", b"gateway_config", "id", b"id", "last_config_ack_time", b"last_config_ack_time", "last_config_send_time", b"last_config_send_time", "last_error_status", b"last_error_status", "last_error_time", b"last_error_time", "last_event_time", b"last_event_time", "last_heartbeat_time", b"last_heartbeat_time", "last_state_time", b"last_state_time", "log_level", b"log_level", "metadata", b"metadata", "name", b"name", "num_id", b"num_id", "registry", b"registry", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts"]) -> None: ...

global___CloudiotDevice = CloudiotDevice

@typing_extensions.final
class CloudiotRegistryXCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PublicKeyCertificateEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PUBLIC_KEY_CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def public_key_certificate(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        public_key_certificate: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_key_certificate", b"public_key_certificate"]) -> None: ...

global___CloudiotRegistryXCredentials = CloudiotRegistryXCredentials

@typing_extensions.final
class CloudiotRegistryXEventNotificationConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_TOPIC_NAME_FIELD_NUMBER: builtins.int
    SUBFOLDER_MATCHES_FIELD_NUMBER: builtins.int
    pubsub_topic_name: builtins.str
    subfolder_matches: builtins.str
    def __init__(
        self,
        *,
        pubsub_topic_name: builtins.str = ...,
        subfolder_matches: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub_topic_name", b"pubsub_topic_name", "subfolder_matches", b"subfolder_matches"]) -> None: ...

global___CloudiotRegistryXEventNotificationConfigs = CloudiotRegistryXEventNotificationConfigs

@typing_extensions.final
class CloudiotRegistryXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudiotRegistryXTimeouts = CloudiotRegistryXTimeouts

@typing_extensions.final
class CloudiotRegistry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HttpConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MqttConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StateNotificationConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    HTTP_CONFIG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    MQTT_CONFIG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    STATE_NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    EVENT_NOTIFICATION_CONFIGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def http_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    id: builtins.str
    log_level: builtins.str
    @property
    def mqtt_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def state_notification_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudiotRegistryXCredentials]: ...
    @property
    def event_notification_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudiotRegistryXEventNotificationConfigs]: ...
    @property
    def timeouts(self) -> global___CloudiotRegistryXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        http_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        id: builtins.str = ...,
        log_level: builtins.str = ...,
        mqtt_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        state_notification_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        credentials: collections.abc.Iterable[global___CloudiotRegistryXCredentials] | None = ...,
        event_notification_configs: collections.abc.Iterable[global___CloudiotRegistryXEventNotificationConfigs] | None = ...,
        timeouts: global___CloudiotRegistryXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "event_notification_configs", b"event_notification_configs", "http_config", b"http_config", "id", b"id", "log_level", b"log_level", "mqtt_config", b"mqtt_config", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "state_notification_config", b"state_notification_config", "timeouts", b"timeouts"]) -> None: ...

global___CloudiotRegistry = CloudiotRegistry

@typing_extensions.final
class CloudiotRegistryIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudiotRegistryIamBindingXCondition = CloudiotRegistryIamBindingXCondition

@typing_extensions.final
class CloudiotRegistryIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudiotRegistryIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudiotRegistryIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudiotRegistryIamBinding = CloudiotRegistryIamBinding

@typing_extensions.final
class CloudiotRegistryIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___CloudiotRegistryIamMemberXCondition = CloudiotRegistryIamMemberXCondition

@typing_extensions.final
class CloudiotRegistryIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___CloudiotRegistryIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___CloudiotRegistryIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___CloudiotRegistryIamMember = CloudiotRegistryIamMember

@typing_extensions.final
class CloudiotRegistryIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "name", b"name", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___CloudiotRegistryIamPolicy = CloudiotRegistryIamPolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_compute_subnetwork_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_subnetwork_pb2 as gcp_dot_gcp__compute__subnetwork__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.gcp/gcp_google_compute_subnetwork_bundle.proto\x12\x30oak9.tython.gcp.google_compute_subnetwork_bundle\x1a\x13shared/shared.proto\x1a gcp/gcp_compute_subnetwork.proto\"\xa3\x03\n\x17GoogleComputeSubnetwork\x12Q\n\x12\x63ompute_subnetwork\x18\x01 \x01(\x0b\x32\x35.oak9.tython.gcp.compute_subnetwork.ComputeSubnetwork\x12g\n\x1e\x63ompute_subnetwork_iam_binding\x18\x02 \x03(\x0b\x32?.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamBinding\x12\x65\n\x1d\x63ompute_subnetwork_iam_member\x18\x03 \x03(\x0b\x32>.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamMember\x12\x65\n\x1d\x63ompute_subnetwork_iam_policy\x18\x04 \x03(\x0b\x32>.oak9.tython.gcp.compute_subnetwork.ComputeSubnetworkIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_compute_subnetwork_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECOMPUTESUBNETWORK._serialized_start=156
  _GOOGLECOMPUTESUBNETWORK._serialized_end=575
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DeploymentManagerDeploymentXLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___DeploymentManagerDeploymentXLabels = DeploymentManagerDeploymentXLabels

@typing_extensions.final
class DeploymentManagerDeploymentXTargetXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___DeploymentManagerDeploymentXTargetXConfig = DeploymentManagerDeploymentXTargetXConfig

@typing_extensions.final
class DeploymentManagerDeploymentXTargetXImports(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    content: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "name", b"name"]) -> None: ...

global___DeploymentManagerDeploymentXTargetXImports = DeploymentManagerDeploymentXTargetXImports

@typing_extensions.final
class DeploymentManagerDeploymentXTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    IMPORTS_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___DeploymentManagerDeploymentXTargetXConfig: ...
    @property
    def imports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentManagerDeploymentXTargetXImports]: ...
    def __init__(
        self,
        *,
        config: global___DeploymentManagerDeploymentXTargetXConfig | None = ...,
        imports: collections.abc.Iterable[global___DeploymentManagerDeploymentXTargetXImports] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "imports", b"imports"]) -> None: ...

global___DeploymentManagerDeploymentXTarget = DeploymentManagerDeploymentXTarget

@typing_extensions.final
class DeploymentManagerDeploymentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DeploymentManagerDeploymentXTimeouts = DeploymentManagerDeploymentXTimeouts

@typing_extensions.final
class DeploymentManagerDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_POLICY_FIELD_NUMBER: builtins.int
    DELETE_POLICY_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MANIFEST_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_policy: builtins.str
    delete_policy: builtins.str
    deployment_id: builtins.str
    description: builtins.str
    id: builtins.str
    manifest: builtins.str
    name: builtins.str
    preview: builtins.bool
    project: builtins.str
    self_link: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentManagerDeploymentXLabels]: ...
    @property
    def target(self) -> global___DeploymentManagerDeploymentXTarget: ...
    @property
    def timeouts(self) -> global___DeploymentManagerDeploymentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_policy: builtins.str = ...,
        delete_policy: builtins.str = ...,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        manifest: builtins.str = ...,
        name: builtins.str = ...,
        preview: builtins.bool = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        labels: collections.abc.Iterable[global___DeploymentManagerDeploymentXLabels] | None = ...,
        target: global___DeploymentManagerDeploymentXTarget | None = ...,
        timeouts: global___DeploymentManagerDeploymentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target", b"target", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_policy", b"create_policy", "delete_policy", b"delete_policy", "deployment_id", b"deployment_id", "description", b"description", "id", b"id", "labels", b"labels", "manifest", b"manifest", "name", b"name", "preview", b"preview", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "target", b"target", "timeouts", b"timeouts"]) -> None: ...

global___DeploymentManagerDeployment = DeploymentManagerDeployment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_external.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_external.proto\x12 oak9.tython.gcp.compute_external\x1a\x13shared/shared.proto\"E\n#ComputeExternalVpnGatewayXInterface\x12\n\n\x02id\x18\x01 \x01(\x01\x12\x12\n\nip_address\x18\x02 \x01(\t\"D\n\"ComputeExternalVpnGatewayXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xf2\x02\n\x19\x43omputeExternalVpnGateway\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x17\n\x0fredundancy_type\x18\x05 \x01(\t\x12\x11\n\tself_link\x18\x06 \x01(\t\x12X\n\tinterface\x18\x07 \x03(\x0b\x32\x45.oak9.tython.gcp.compute_external.ComputeExternalVpnGatewayXInterface\x12V\n\x08timeouts\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_external.ComputeExternalVpnGatewayXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_external_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEEXTERNALVPNGATEWAYXINTERFACE._serialized_start=89
  _COMPUTEEXTERNALVPNGATEWAYXINTERFACE._serialized_end=158
  _COMPUTEEXTERNALVPNGATEWAYXTIMEOUTS._serialized_start=160
  _COMPUTEEXTERNALVPNGATEWAYXTIMEOUTS._serialized_end=228
  _COMPUTEEXTERNALVPNGATEWAY._serialized_start=231
  _COMPUTEEXTERNALVPNGATEWAY._serialized_end=601
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codecommit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_codecommit.proto\x12\x1aoak9.tython.aws.codecommit\x1a\x13shared/shared.proto\"\xb4\x01\n\x1bRepositoryRepositoryTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x65vents\x18\x02 \x03(\t\x12\x10\n\x08\x62ranches\x18\x03 \x03(\t\x12\x13\n\x0b\x63ustom_data\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x65stination_arn\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"|\n\x0cRepositoryS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eobject_version\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"\x94\x01\n\x0eRepositoryCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x34\n\x02s3\x18\x02 \x01(\x0b\x32(.oak9.tython.aws.codecommit.RepositoryS3\x12\x13\n\x0b\x62ranch_name\x18\x03 \x01(\t\"\xf0\x02\n\nRepository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12I\n\x08triggers\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.codecommit.RepositoryRepositoryTrigger\x12\x38\n\x04\x63ode\x18\x04 \x01(\x0b\x32*.oak9.tython.aws.codecommit.RepositoryCode\x12\x1e\n\x16repository_description\x18\x05 \x01(\t\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.codecommit.Repository.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\nCodeCommit\x12:\n\nrepository\x18\x01 \x03(\x0b\x32&.oak9.tython.aws.codecommit.Repositoryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codecommit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPOSITORY_TAGSENTRY._options = None
  _REPOSITORY_TAGSENTRY._serialized_options = b'8\001'
  _REPOSITORYREPOSITORYTRIGGER._serialized_start=78
  _REPOSITORYREPOSITORYTRIGGER._serialized_end=258
  _REPOSITORYS3._serialized_start=260
  _REPOSITORYS3._serialized_end=384
  _REPOSITORYCODE._serialized_start=387
  _REPOSITORYCODE._serialized_end=535
  _REPOSITORY._serialized_start=538
  _REPOSITORY._serialized_end=906
  _REPOSITORY_TAGSENTRY._serialized_start=863
  _REPOSITORY_TAGSENTRY._serialized_end=906
  _CODECOMMIT._serialized_start=908
  _CODECOMMIT._serialized_end=980
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.admissionregistration.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?kubernetes/kubernetes_io.k8s.api.admissionregistration.v1.proto\x12,oak9.tython.k8s.api.admissionregistration.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xd1\x04\n\x0fMutatingWebhook\x12!\n\x19\x61\x64mission_review_versions\x18\x01 \x03(\t\x12X\n\rclient_config\x18\x02 \x01(\x0b\x32\x41.oak9.tython.k8s.api.admissionregistration.v1.WebhookClientConfig\x12\x16\n\x0e\x66\x61ilure_policy\x18\x03 \x01(\t\x12\x14\n\x0cmatch_policy\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12X\n\x12namespace_selector\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12U\n\x0fobject_selector\x18\x07 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x1b\n\x13reinvocation_policy\x18\x08 \x01(\t\x12O\n\x05rules\x18\t \x03(\x0b\x32@.oak9.tython.k8s.api.admissionregistration.v1.RuleWithOperations\x12\x14\n\x0cside_effects\x18\n \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x0b \x01(\x05\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x98\x02\n\x1cMutatingWebhookConfiguration\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x08webhooks\x18\x04 \x03(\x0b\x32=.oak9.tython.k8s.api.admissionregistration.v1.MutatingWebhook\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x02\n MutatingWebhookConfigurationList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12Y\n\x05items\x18\x02 \x03(\x0b\x32J.oak9.tython.k8s.api.admissionregistration.v1.MutatingWebhookConfiguration\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x01\n\x12RuleWithOperations\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x14\n\x0c\x61pi_versions\x18\x02 \x03(\t\x12\x12\n\noperations\x18\x03 \x03(\t\x12\x11\n\tresources\x18\x04 \x03(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x01\n\x10ServiceReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x04\n\x11ValidatingWebhook\x12!\n\x19\x61\x64mission_review_versions\x18\x01 \x03(\t\x12X\n\rclient_config\x18\x02 \x01(\x0b\x32\x41.oak9.tython.k8s.api.admissionregistration.v1.WebhookClientConfig\x12\x16\n\x0e\x66\x61ilure_policy\x18\x03 \x01(\t\x12\x14\n\x0cmatch_policy\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12X\n\x12namespace_selector\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12U\n\x0fobject_selector\x18\x07 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12O\n\x05rules\x18\x08 \x03(\x0b\x32@.oak9.tython.k8s.api.admissionregistration.v1.RuleWithOperations\x12\x14\n\x0cside_effects\x18\t \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\n \x01(\x05\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x02\n\x1eValidatingWebhookConfiguration\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Q\n\x08webhooks\x18\x04 \x03(\x0b\x32?.oak9.tython.k8s.api.admissionregistration.v1.ValidatingWebhook\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa8\x02\n\"ValidatingWebhookConfigurationList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12[\n\x05items\x18\x02 \x03(\x0b\x32L.oak9.tython.k8s.api.admissionregistration.v1.ValidatingWebhookConfiguration\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x01\n\x13WebhookClientConfig\x12\x11\n\tca_bundle\x18\x01 \x01(\t\x12O\n\x07service\x18\x02 \x01(\x0b\x32>.oak9.tython.k8s.api.admissionregistration.v1.ServiceReference\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.admissionregistration.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MUTATINGWEBHOOK._serialized_start=201
  _MUTATINGWEBHOOK._serialized_end=794
  _MUTATINGWEBHOOKCONFIGURATION._serialized_start=797
  _MUTATINGWEBHOOKCONFIGURATION._serialized_end=1077
  _MUTATINGWEBHOOKCONFIGURATIONLIST._serialized_start=1080
  _MUTATINGWEBHOOKCONFIGURATIONLIST._serialized_end=1372
  _RULEWITHOPERATIONS._serialized_start=1375
  _RULEWITHOPERATIONS._serialized_end=1548
  _SERVICEREFERENCE._serialized_start=1551
  _SERVICEREFERENCE._serialized_end=1687
  _VALIDATINGWEBHOOK._serialized_start=1690
  _VALIDATINGWEBHOOK._serialized_end=2256
  _VALIDATINGWEBHOOKCONFIGURATION._serialized_start=2259
  _VALIDATINGWEBHOOKCONFIGURATION._serialized_end=2543
  _VALIDATINGWEBHOOKCONFIGURATIONLIST._serialized_start=2546
  _VALIDATINGWEBHOOKCONFIGURATIONLIST._serialized_end=2842
  _WEBHOOKCLIENTCONFIG._serialized_start=2845
  _WEBHOOKCLIENTCONFIG._serialized_end=3036
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_ec2_route.proto\x12\x19oak9.tython.aws.ec2_route\x1a\x13shared/shared.proto\"\xe4\x02\n\x05Route\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65stination_cidr_block\x18\x02 \x01(\t\x12#\n\x1b\x64\x65stination_ipv6_cidr_block\x18\x03 \x01(\t\x12\'\n\x1f\x65gress_only_internet_gateway_id\x18\x04 \x01(\t\x12\x12\n\ngateway_id\x18\x05 \x01(\t\x12\x13\n\x0binstance_id\x18\x06 \x01(\t\x12\x16\n\x0enat_gateway_id\x18\x07 \x01(\t\x12\x1c\n\x14network_interface_id\x18\x08 \x01(\t\x12\x16\n\x0eroute_table_id\x18\t \x01(\t\x12\x1a\n\x12transit_gateway_id\x18\n \x01(\t\x12!\n\x19vpc_peering_connection_id\x18\x0b \x01(\t\"x\n\tEC2_Route\x12/\n\x05route\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.ec2_route.Route\x12:\n\x0broute_table\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.ec2_route.RouteTable\"\xc1\x01\n\nRouteTable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x04tags\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.ec2_route.RouteTable.TagsEntry\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_route_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROUTETABLE_TAGSENTRY._options = None
  _ROUTETABLE_TAGSENTRY._serialized_options = b'8\001'
  _ROUTE._serialized_start=76
  _ROUTE._serialized_end=432
  _EC2_ROUTE._serialized_start=434
  _EC2_ROUTE._serialized_end=554
  _ROUTETABLE._serialized_start=557
  _ROUTETABLE._serialized_end=750
  _ROUTETABLE_TAGSENTRY._serialized_start=707
  _ROUTETABLE_TAGSENTRY._serialized_end=750
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LocalSubjectAccessReview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___SubjectAccessReviewSpec: ...
    @property
    def status(self) -> global___SubjectAccessReviewStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___SubjectAccessReviewSpec | None = ...,
        status: global___SubjectAccessReviewStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___LocalSubjectAccessReview = LocalSubjectAccessReview

@typing_extensions.final
class NonResourceAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    VERB_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    path: builtins.str
    verb: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        verb: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "resource_info", b"resource_info", "verb", b"verb"]) -> None: ...

global___NonResourceAttributes = NonResourceAttributes

@typing_extensions.final
class NonResourceRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NON_RESOURCE_U_R_LS_FIELD_NUMBER: builtins.int
    VERBS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def non_resource_u_r_ls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def verbs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        non_resource_u_r_ls: collections.abc.Iterable[builtins.str] | None = ...,
        verbs: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["non_resource_u_r_ls", b"non_resource_u_r_ls", "resource_info", b"resource_info", "verbs", b"verbs"]) -> None: ...

global___NonResourceRule = NonResourceRule

@typing_extensions.final
class ResourceAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    SUBRESOURCE_FIELD_NUMBER: builtins.int
    VERB_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    group: builtins.str
    name: builtins.str
    namespace: builtins.str
    resource: builtins.str
    subresource: builtins.str
    verb: builtins.str
    version: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        group: builtins.str = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource: builtins.str = ...,
        subresource: builtins.str = ...,
        verb: builtins.str = ...,
        version: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group", b"group", "name", b"name", "namespace", b"namespace", "resource", b"resource", "resource_info", b"resource_info", "subresource", b"subresource", "verb", b"verb", "version", b"version"]) -> None: ...

global___ResourceAttributes = ResourceAttributes

@typing_extensions.final
class ResourceRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUPS_FIELD_NUMBER: builtins.int
    RESOURCE_NAMES_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    VERBS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def api_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def verbs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_groups: collections.abc.Iterable[builtins.str] | None = ...,
        resource_names: collections.abc.Iterable[builtins.str] | None = ...,
        resources: collections.abc.Iterable[builtins.str] | None = ...,
        verbs: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_groups", b"api_groups", "resource_info", b"resource_info", "resource_names", b"resource_names", "resources", b"resources", "verbs", b"verbs"]) -> None: ...

global___ResourceRule = ResourceRule

@typing_extensions.final
class SelfSubjectAccessReview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___SelfSubjectAccessReviewSpec: ...
    @property
    def status(self) -> global___SubjectAccessReviewStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___SelfSubjectAccessReviewSpec | None = ...,
        status: global___SubjectAccessReviewStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___SelfSubjectAccessReview = SelfSubjectAccessReview

@typing_extensions.final
class SelfSubjectAccessReviewSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NON_RESOURCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    RESOURCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def non_resource_attributes(self) -> global___NonResourceAttributes: ...
    @property
    def resource_attributes(self) -> global___ResourceAttributes: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        non_resource_attributes: global___NonResourceAttributes | None = ...,
        resource_attributes: global___ResourceAttributes | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["non_resource_attributes", b"non_resource_attributes", "resource_attributes", b"resource_attributes", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["non_resource_attributes", b"non_resource_attributes", "resource_attributes", b"resource_attributes", "resource_info", b"resource_info"]) -> None: ...

global___SelfSubjectAccessReviewSpec = SelfSubjectAccessReviewSpec

@typing_extensions.final
class SelfSubjectRulesReview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___SelfSubjectRulesReviewSpec: ...
    @property
    def status(self) -> global___SubjectRulesReviewStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___SelfSubjectRulesReviewSpec | None = ...,
        status: global___SubjectRulesReviewStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___SelfSubjectRulesReview = SelfSubjectRulesReview

@typing_extensions.final
class SelfSubjectRulesReviewSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___SelfSubjectRulesReviewSpec = SelfSubjectRulesReviewSpec

@typing_extensions.final
class SubjectAccessReview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___SubjectAccessReviewSpec: ...
    @property
    def status(self) -> global___SubjectAccessReviewStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___SubjectAccessReviewSpec | None = ...,
        status: global___SubjectAccessReviewStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___SubjectAccessReview = SubjectAccessReview

@typing_extensions.final
class SubjectAccessReviewSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    EXTRA_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    NON_RESOURCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    RESOURCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def non_resource_attributes(self) -> global___NonResourceAttributes: ...
    @property
    def resource_attributes(self) -> global___ResourceAttributes: ...
    uid: builtins.str
    user: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        non_resource_attributes: global___NonResourceAttributes | None = ...,
        resource_attributes: global___ResourceAttributes | None = ...,
        uid: builtins.str = ...,
        user: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["non_resource_attributes", b"non_resource_attributes", "resource_attributes", b"resource_attributes", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra", b"extra", "groups", b"groups", "non_resource_attributes", b"non_resource_attributes", "resource_attributes", b"resource_attributes", "resource_info", b"resource_info", "uid", b"uid", "user", b"user"]) -> None: ...

global___SubjectAccessReviewSpec = SubjectAccessReviewSpec

@typing_extensions.final
class SubjectAccessReviewStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_FIELD_NUMBER: builtins.int
    DENIED_FIELD_NUMBER: builtins.int
    EVALUATION_ERROR_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allowed: builtins.bool
    denied: builtins.bool
    evaluation_error: builtins.str
    reason: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allowed: builtins.bool = ...,
        denied: builtins.bool = ...,
        evaluation_error: builtins.str = ...,
        reason: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed", b"allowed", "denied", b"denied", "evaluation_error", b"evaluation_error", "reason", b"reason", "resource_info", b"resource_info"]) -> None: ...

global___SubjectAccessReviewStatus = SubjectAccessReviewStatus

@typing_extensions.final
class SubjectRulesReviewStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVALUATION_ERROR_FIELD_NUMBER: builtins.int
    INCOMPLETE_FIELD_NUMBER: builtins.int
    NON_RESOURCE_RULES_FIELD_NUMBER: builtins.int
    RESOURCE_RULES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    evaluation_error: builtins.str
    incomplete: builtins.bool
    @property
    def non_resource_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NonResourceRule]: ...
    @property
    def resource_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceRule]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        evaluation_error: builtins.str = ...,
        incomplete: builtins.bool = ...,
        non_resource_rules: collections.abc.Iterable[global___NonResourceRule] | None = ...,
        resource_rules: collections.abc.Iterable[global___ResourceRule] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["evaluation_error", b"evaluation_error", "incomplete", b"incomplete", "non_resource_rules", b"non_resource_rules", "resource_info", b"resource_info", "resource_rules", b"resource_rules"]) -> None: ...

global___SubjectRulesReviewStatus = SubjectRulesReviewStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_secretsmanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_secretsmanager.proto\x12\x1eoak9.tython.aws.secretsmanager\x1a\x13shared/shared.proto\"u\n\x0eResourcePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12\x17\n\x0fresource_policy\x18\x03 \x01(\t\"\xb8\x02\n\x0eSecretsManager\x12G\n\x0fresource_policy\x18\x01 \x01(\x0b\x32..oak9.tython.aws.secretsmanager.ResourcePolicy\x12K\n\x11rotation_schedule\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.secretsmanager.RotationSchedule\x12\x36\n\x06secret\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.secretsmanager.Secret\x12X\n\x18secret_target_attachment\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.secretsmanager.SecretTargetAttachment\"\x9f\x02\n$RotationScheduleHostedRotationLambda\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rrotation_type\x18\x02 \x01(\t\x12\x1c\n\x14rotation_lambda_name\x18\x03 \x01(\t\x12\x13\n\x0bkms_key_arn\x18\x04 \x01(\t\x12\x19\n\x11master_secret_arn\x18\x05 \x01(\t\x12\x1e\n\x16vpc_security_group_ids\x18\x06 \x01(\t\x12!\n\x19master_secret_kms_key_arn\x18\x07 \x01(\t\x12\x16\n\x0evpc_subnet_ids\x18\x08 \x01(\t\"z\n\x1dRotationScheduleRotationRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18\x61utomatically_after_days\x18\x02 \x01(\x05\"\xb8\x02\n\x10RotationSchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12\x64\n\x16hosted_rotation_lambda\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.secretsmanager.RotationScheduleHostedRotationLambda\x12\x1b\n\x13rotation_lambda_arn\x18\x04 \x01(\t\x12U\n\x0erotation_rules\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.secretsmanager.RotationScheduleRotationRules\"\xee\x02\n\x1aSecretGenerateSecretString\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x65xclude_uppercase\x18\x02 \x01(\x08\x12\"\n\x1arequire_each_included_type\x18\x03 \x01(\x08\x12\x15\n\rinclude_space\x18\x04 \x01(\x08\x12\x1a\n\x12\x65xclude_characters\x18\x05 \x01(\t\x12\x1b\n\x13generate_string_key\x18\x06 \x01(\t\x12\x17\n\x0fpassword_length\x18\x07 \x01(\x05\x12\x1b\n\x13\x65xclude_punctuation\x18\x08 \x01(\x08\x12\x19\n\x11\x65xclude_lowercase\x18\t \x01(\x08\x12\x1e\n\x16secret_string_template\x18\n \x01(\t\x12\x17\n\x0f\x65xclude_numbers\x18\x0b \x01(\x08\"\xd8\x02\n\x06Secret\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nkms_key_id\x18\x03 \x01(\t\x12\x15\n\rsecret_string\x18\x04 \x01(\t\x12Z\n\x16generate_secret_string\x18\x05 \x01(\x0b\x32:.oak9.tython.aws.secretsmanager.SecretGenerateSecretString\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.secretsmanager.Secret.TagsEntry\x12\x0c\n\x04name\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x16SecretTargetAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12\x13\n\x0btarget_type\x18\x03 \x01(\t\x12\x11\n\ttarget_id\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_secretsmanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SECRET_TAGSENTRY._options = None
  _SECRET_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCEPOLICY._serialized_start=85
  _RESOURCEPOLICY._serialized_end=202
  _SECRETSMANAGER._serialized_start=205
  _SECRETSMANAGER._serialized_end=517
  _ROTATIONSCHEDULEHOSTEDROTATIONLAMBDA._serialized_start=520
  _ROTATIONSCHEDULEHOSTEDROTATIONLAMBDA._serialized_end=807
  _ROTATIONSCHEDULEROTATIONRULES._serialized_start=809
  _ROTATIONSCHEDULEROTATIONRULES._serialized_end=931
  _ROTATIONSCHEDULE._serialized_start=934
  _ROTATIONSCHEDULE._serialized_end=1246
  _SECRETGENERATESECRETSTRING._serialized_start=1249
  _SECRETGENERATESECRETSTRING._serialized_end=1615
  _SECRET._serialized_start=1618
  _SECRET._serialized_end=1962
  _SECRET_TAGSENTRY._serialized_start=1919
  _SECRET_TAGSENTRY._serialized_end=1962
  _SECRETTARGETATTACHMENT._serialized_start=1965
  _SECRETTARGETATTACHMENT._serialized_end=2105
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputePacketMirroringXCollectorIlb(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXCollectorIlb = ComputePacketMirroringXCollectorIlb

@typing_extensions.final
class ComputePacketMirroringXFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIDR_RANGES_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    IP_PROTOCOLS_FIELD_NUMBER: builtins.int
    @property
    def cidr_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    direction: builtins.str
    @property
    def ip_protocols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        cidr_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        direction: builtins.str = ...,
        ip_protocols: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_ranges", b"cidr_ranges", "direction", b"direction", "ip_protocols", b"ip_protocols"]) -> None: ...

global___ComputePacketMirroringXFilter = ComputePacketMirroringXFilter

@typing_extensions.final
class ComputePacketMirroringXMirroredResourcesXInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXMirroredResourcesXInstances = ComputePacketMirroringXMirroredResourcesXInstances

@typing_extensions.final
class ComputePacketMirroringXMirroredResourcesXSubnetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXMirroredResourcesXSubnetworks = ComputePacketMirroringXMirroredResourcesXSubnetworks

@typing_extensions.final
class ComputePacketMirroringXMirroredResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAGS_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    SUBNETWORKS_FIELD_NUMBER: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputePacketMirroringXMirroredResourcesXInstances]: ...
    @property
    def subnetworks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputePacketMirroringXMirroredResourcesXSubnetworks]: ...
    def __init__(
        self,
        *,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        instances: collections.abc.Iterable[global___ComputePacketMirroringXMirroredResourcesXInstances] | None = ...,
        subnetworks: collections.abc.Iterable[global___ComputePacketMirroringXMirroredResourcesXSubnetworks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instances", b"instances", "subnetworks", b"subnetworks", "tags", b"tags"]) -> None: ...

global___ComputePacketMirroringXMirroredResources = ComputePacketMirroringXMirroredResources

@typing_extensions.final
class ComputePacketMirroringXNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ComputePacketMirroringXNetwork = ComputePacketMirroringXNetwork

@typing_extensions.final
class ComputePacketMirroringXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputePacketMirroringXTimeouts = ComputePacketMirroringXTimeouts

@typing_extensions.final
class ComputePacketMirroring(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    COLLECTOR_ILB_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    MIRRORED_RESOURCES_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    priority: builtins.float
    project: builtins.str
    region: builtins.str
    @property
    def collector_ilb(self) -> global___ComputePacketMirroringXCollectorIlb: ...
    @property
    def filter(self) -> global___ComputePacketMirroringXFilter: ...
    @property
    def mirrored_resources(self) -> global___ComputePacketMirroringXMirroredResources: ...
    @property
    def network(self) -> global___ComputePacketMirroringXNetwork: ...
    @property
    def timeouts(self) -> global___ComputePacketMirroringXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        priority: builtins.float = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        collector_ilb: global___ComputePacketMirroringXCollectorIlb | None = ...,
        filter: global___ComputePacketMirroringXFilter | None = ...,
        mirrored_resources: global___ComputePacketMirroringXMirroredResources | None = ...,
        network: global___ComputePacketMirroringXNetwork | None = ...,
        timeouts: global___ComputePacketMirroringXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["collector_ilb", b"collector_ilb", "filter", b"filter", "mirrored_resources", b"mirrored_resources", "network", b"network", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collector_ilb", b"collector_ilb", "description", b"description", "filter", b"filter", "id", b"id", "mirrored_resources", b"mirrored_resources", "name", b"name", "network", b"network", "priority", b"priority", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputePacketMirroring = ComputePacketMirroring



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssessmentTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSESSMENT_TARGET_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    assessment_target_name: builtins.str
    resource_group_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        assessment_target_name: builtins.str = ...,
        resource_group_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_target_name", b"assessment_target_name", "resource_group_arn", b"resource_group_arn", "resource_info", b"resource_info"]) -> None: ...

global___AssessmentTarget = AssessmentTarget

@typing_extensions.final
class Inspector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSESSMENT_TARGET_FIELD_NUMBER: builtins.int
    ASSESSMENT_TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    @property
    def assessment_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssessmentTarget]: ...
    @property
    def assessment_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssessmentTemplate]: ...
    @property
    def resource_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceGroup]: ...
    def __init__(
        self,
        *,
        assessment_target: collections.abc.Iterable[global___AssessmentTarget] | None = ...,
        assessment_template: collections.abc.Iterable[global___AssessmentTemplate] | None = ...,
        resource_group: collections.abc.Iterable[global___ResourceGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_target", b"assessment_target", "assessment_template", b"assessment_template", "resource_group", b"resource_group"]) -> None: ...

global___Inspector = Inspector

@typing_extensions.final
class AssessmentTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAttributesForFindingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSESSMENT_TARGET_ARN_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    ASSESSMENT_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    RULES_PACKAGE_ARNS_FIELD_NUMBER: builtins.int
    USER_ATTRIBUTES_FOR_FINDINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    assessment_target_arn: builtins.str
    duration_in_seconds: builtins.int
    assessment_template_name: builtins.str
    @property
    def rules_package_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def user_attributes_for_findings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        assessment_target_arn: builtins.str = ...,
        duration_in_seconds: builtins.int = ...,
        assessment_template_name: builtins.str = ...,
        rules_package_arns: collections.abc.Iterable[builtins.str] | None = ...,
        user_attributes_for_findings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_target_arn", b"assessment_target_arn", "assessment_template_name", b"assessment_template_name", "duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info", "rules_package_arns", b"rules_package_arns", "user_attributes_for_findings", b"user_attributes_for_findings"]) -> None: ...

global___AssessmentTemplate = AssessmentTemplate

@typing_extensions.final
class ResourceGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResourceGroupTagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def resource_group_tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_group_tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_group_tags", b"resource_group_tags", "resource_info", b"resource_info"]) -> None: ...

global___ResourceGroup = ResourceGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_eventgrid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%azure/azure_microsoft_eventgrid.proto\x12%oak9.tython.azure.microsoft_eventgrid\x1a\x13shared/shared.proto\"\xd1\x03\n\x13Microsoft_EventGrid\x12?\n\x07\x64omains\x18\x01 \x01(\x0b\x32..oak9.tython.azure.microsoft_eventgrid.Domains\x12v\n$domains_private_endpoint_connections\x18\x02 \x03(\x0b\x32H.oak9.tython.azure.microsoft_eventgrid.DomainsPrivateEndpointConnections\x12L\n\x0e\x64omains_topics\x18\x03 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_eventgrid.DomainsTopics\x12=\n\x06topics\x18\x04 \x01(\x0b\x32-.oak9.tython.azure.microsoft_eventgrid.Topics\x12t\n#topics_private_endpoint_connections\x18\x05 \x03(\x0b\x32G.oak9.tython.azure.microsoft_eventgrid.TopicsPrivateEndpointConnections\"\xd1\x02\n TopicsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tgroup_ids\x18\x03 \x03(\t\x12P\n\x10private_endpoint\x18\x04 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.PrivateEndpoint\x12\x65\n%private_link_service_connection_state\x18\x05 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\"\x96\x04\n\x06Topics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x08identity\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_eventgrid.IdentityInfo\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1a\n\x12\x64isable_local_auth\x18\x05 \x01(\x08\x12N\n\x10inbound_ip_rules\x18\x06 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_eventgrid.InboundIpRule\x12\x14\n\x0cinput_schema\x18\x07 \x01(\t\x12W\n\x14input_schema_mapping\x18\x08 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_eventgrid.InputSchemaMapping\x12\x1d\n\x15public_network_access\x18\t \x01(\t\x12\x45\n\x04tags\x18\n \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_eventgrid.Topics.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe7\x05\n\x1eSystemTopicsEventSubscriptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12]\n\x17\x64\x65\x61\x64_letter_destination\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_eventgrid.DeadLetterDestination\x12q\n\"dead_letter_with_resource_identity\x18\x04 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_eventgrid.DeadLetterWithResourceIdentity\x12l\n\x1f\x64\x65livery_with_resource_identity\x18\x05 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_eventgrid.DeliveryWithResourceIdentity\x12X\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionDestination\x12\x1d\n\x15\x65vent_delivery_schema\x18\x07 \x01(\t\x12\x1b\n\x13\x65xpiration_time_utc\x18\x08 \x01(\t\x12N\n\x06\x66ilter\x18\t \x01(\x0b\x32>.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionFilter\x12\x0e\n\x06labels\x18\n \x03(\t\x12H\n\x0cretry_policy\x18\x0b \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_eventgrid.RetryPolicy\"S\n\x0bRetryPolicy\x12%\n\x1d\x65vent_time_to_live_in_minutes\x18\x01 \x01(\x05\x12\x1d\n\x15max_delivery_attempts\x18\x02 \x01(\x05\"\x90\x02\n\x17\x45ventSubscriptionFilter\x12O\n\x10\x61\x64vanced_filters\x18\x01 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_eventgrid.AdvancedFilter\x12+\n#enable_advanced_filtering_on_arrays\x18\x02 \x01(\x08\x12\x1c\n\x14included_event_types\x18\x03 \x03(\t\x12!\n\x19is_subject_case_sensitive\x18\x04 \x01(\x08\x12\x1b\n\x13subject_begins_with\x18\x05 \x01(\t\x12\x19\n\x11subject_ends_with\x18\x06 \x01(\t\"\x1d\n\x0e\x41\x64vancedFilter\x12\x0b\n\x03key\x18\x01 \x01(\t\"\xcc\x01\n\x1c\x44\x65liveryWithResourceIdentity\x12X\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionDestination\x12R\n\x08identity\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionIdentity\",\n\x1c\x45ventSubscriptionDestination\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xd3\x01\n\x1e\x44\x65\x61\x64LetterWithResourceIdentity\x12]\n\x17\x64\x65\x61\x64_letter_destination\x18\x01 \x01(\x0b\x32<.oak9.tython.azure.microsoft_eventgrid.DeadLetterDestination\x12R\n\x08identity\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_eventgrid.EventSubscriptionIdentity\"I\n\x19\x45ventSubscriptionIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1e\n\x16user_assigned_identity\x18\x02 \x01(\t\"%\n\x15\x44\x65\x61\x64LetterDestination\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xbe\x03\n\x0cSystemTopics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x08identity\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_eventgrid.IdentityInfo\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12\x12\n\ntopic_type\x18\x06 \x01(\t\x12K\n\x04tags\x18\x07 \x03(\x0b\x32=.oak9.tython.azure.microsoft_eventgrid.SystemTopics.TagsEntry\x12p\n!system_topics_event_subscriptions\x18\x08 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_eventgrid.SystemTopicsEventSubscriptions\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\rDomainsTopics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd2\x02\n!DomainsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tgroup_ids\x18\x03 \x03(\t\x12P\n\x10private_endpoint\x18\x04 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.PrivateEndpoint\x12\x65\n%private_link_service_connection_state\x18\x05 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_eventgrid.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\"P\n\x0f\x43onnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\xfd\x04\n\x07\x44omains\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x08identity\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_eventgrid.IdentityInfo\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x31\n)auto_create_topic_with_first_subscription\x18\x05 \x01(\x08\x12\x30\n(auto_delete_topic_with_last_subscription\x18\x06 \x01(\x08\x12\x1a\n\x12\x64isable_local_auth\x18\x07 \x01(\x08\x12N\n\x10inbound_ip_rules\x18\x08 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_eventgrid.InboundIpRule\x12\x14\n\x0cinput_schema\x18\t \x01(\t\x12W\n\x14input_schema_mapping\x18\n \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_eventgrid.InputSchemaMapping\x12\x1d\n\x15public_network_access\x18\x0b \x01(\t\x12\x46\n\x04tags\x18\x0c \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_eventgrid.Domains.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\x12InputSchemaMapping\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\rInboundIpRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0f\n\x07ip_mask\x18\x02 \x01(\t\"\xf7\x01\n\x0cIdentityInfo\x12\x14\n\x0cprincipal_id\x18\x01 \x01(\t\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12q\n\x18user_assigned_identities\x18\x04 \x03(\x0b\x32O.oak9.tython.azure.microsoft_eventgrid.IdentityInfo.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_eventgrid_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOPICS_TAGSENTRY._options = None
  _TOPICS_TAGSENTRY._serialized_options = b'8\001'
  _SYSTEMTOPICS_TAGSENTRY._options = None
  _SYSTEMTOPICS_TAGSENTRY._serialized_options = b'8\001'
  _DOMAINS_TAGSENTRY._options = None
  _DOMAINS_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_EVENTGRID._serialized_start=102
  _MICROSOFT_EVENTGRID._serialized_end=567
  _TOPICSPRIVATEENDPOINTCONNECTIONS._serialized_start=570
  _TOPICSPRIVATEENDPOINTCONNECTIONS._serialized_end=907
  _TOPICS._serialized_start=910
  _TOPICS._serialized_end=1444
  _TOPICS_TAGSENTRY._serialized_start=1401
  _TOPICS_TAGSENTRY._serialized_end=1444
  _SYSTEMTOPICSEVENTSUBSCRIPTIONS._serialized_start=1447
  _SYSTEMTOPICSEVENTSUBSCRIPTIONS._serialized_end=2190
  _RETRYPOLICY._serialized_start=2192
  _RETRYPOLICY._serialized_end=2275
  _EVENTSUBSCRIPTIONFILTER._serialized_start=2278
  _EVENTSUBSCRIPTIONFILTER._serialized_end=2550
  _ADVANCEDFILTER._serialized_start=2552
  _ADVANCEDFILTER._serialized_end=2581
  _DELIVERYWITHRESOURCEIDENTITY._serialized_start=2584
  _DELIVERYWITHRESOURCEIDENTITY._serialized_end=2788
  _EVENTSUBSCRIPTIONDESTINATION._serialized_start=2790
  _EVENTSUBSCRIPTIONDESTINATION._serialized_end=2834
  _DEADLETTERWITHRESOURCEIDENTITY._serialized_start=2837
  _DEADLETTERWITHRESOURCEIDENTITY._serialized_end=3048
  _EVENTSUBSCRIPTIONIDENTITY._serialized_start=3050
  _EVENTSUBSCRIPTIONIDENTITY._serialized_end=3123
  _DEADLETTERDESTINATION._serialized_start=3125
  _DEADLETTERDESTINATION._serialized_end=3162
  _SYSTEMTOPICS._serialized_start=3165
  _SYSTEMTOPICS._serialized_end=3611
  _SYSTEMTOPICS_TAGSENTRY._serialized_start=1401
  _SYSTEMTOPICS_TAGSENTRY._serialized_end=1444
  _DOMAINSTOPICS._serialized_start=3613
  _DOMAINSTOPICS._serialized_end=3699
  _DOMAINSPRIVATEENDPOINTCONNECTIONS._serialized_start=3702
  _DOMAINSPRIVATEENDPOINTCONNECTIONS._serialized_end=4040
  _CONNECTIONSTATE._serialized_start=4042
  _CONNECTIONSTATE._serialized_end=4122
  _PRIVATEENDPOINT._serialized_start=4124
  _PRIVATEENDPOINT._serialized_end=4153
  _DOMAINS._serialized_start=4156
  _DOMAINS._serialized_end=4793
  _DOMAINS_TAGSENTRY._serialized_start=1401
  _DOMAINS_TAGSENTRY._serialized_end=1444
  _INPUTSCHEMAMAPPING._serialized_start=4795
  _INPUTSCHEMAMAPPING._serialized_end=4829
  _INBOUNDIPRULE._serialized_start=4831
  _INBOUNDIPRULE._serialized_end=4879
  _IDENTITYINFO._serialized_start=4882
  _IDENTITYINFO._serialized_end=5129
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._serialized_start=5068
  _IDENTITYINFO_USERASSIGNEDIDENTITIESENTRY._serialized_end=5129
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_fsx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_fsx.proto\x12\x13oak9.tython.aws.fsx\x1a\x13shared/shared.proto\"\xb1\x03\n\x1d\x46ileSystemLustreConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x64rive_cache_type\x18\x02 \x01(\t\x12\x13\n\x0bimport_path\x18\x03 \x01(\t\x12%\n\x1dweekly_maintenance_start_time\x18\x04 \x01(\t\x12\x1a\n\x12\x61uto_import_policy\x18\x05 \x01(\t\x12 \n\x18imported_file_chunk_size\x18\x06 \x01(\x05\x12\x17\n\x0f\x64\x65ployment_type\x18\x07 \x01(\t\x12)\n!daily_automatic_backup_start_time\x18\x08 \x01(\t\x12\x1c\n\x14\x63opy_tags_to_backups\x18\t \x01(\x08\x12\x13\n\x0b\x65xport_path\x18\n \x01(\t\x12#\n\x1bper_unit_storage_throughput\x18\x0b \x01(\x05\x12\'\n\x1f\x61utomatic_backup_retention_days\x18\x0c \x01(\x05\"\x91\x02\n1FileSystemSelfManagedActiveDirectoryConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12(\n file_system_administrators_group\x18\x02 \x01(\t\x12\x11\n\tuser_name\x18\x03 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x04 \x01(\t\x12.\n&organizational_unit_distinguished_name\x18\x05 \x01(\t\x12\x0f\n\x07\x64ns_ips\x18\x06 \x03(\t\x12\x10\n\x08password\x18\x07 \x01(\t\"\xdf\x03\n\x1e\x46ileSystemWindowsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12{\n+self_managed_active_directory_configuration\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.fsx.FileSystemSelfManagedActiveDirectoryConfiguration\x12%\n\x1dweekly_maintenance_start_time\x18\x03 \x01(\t\x12\x1b\n\x13\x61\x63tive_directory_id\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x65ployment_type\x18\x05 \x01(\t\x12\x1b\n\x13throughput_capacity\x18\x06 \x01(\x05\x12\x1c\n\x14\x63opy_tags_to_backups\x18\x07 \x01(\x08\x12)\n!daily_automatic_backup_start_time\x18\x08 \x01(\t\x12\'\n\x1f\x61utomatic_backup_retention_days\x18\t \x01(\x05\x12\x1b\n\x13preferred_subnet_id\x18\n \x01(\t\"\xf2\x03\n\nFileSystem\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cstorage_type\x18\x02 \x01(\t\x12\x12\n\nkms_key_id\x18\x03 \x01(\t\x12\x18\n\x10storage_capacity\x18\x04 \x01(\x05\x12\x18\n\x10\x66ile_system_type\x18\x05 \x01(\t\x12P\n\x14lustre_configuration\x18\x06 \x01(\x0b\x32\x32.oak9.tython.aws.fsx.FileSystemLustreConfiguration\x12\x11\n\tbackup_id\x18\x07 \x01(\t\x12\x12\n\nsubnet_ids\x18\x08 \x03(\t\x12\x1a\n\x12security_group_ids\x18\t \x03(\t\x12\x37\n\x04tags\x18\n \x03(\x0b\x32).oak9.tython.aws.fsx.FileSystem.TagsEntry\x12R\n\x15windows_configuration\x18\x0b \x01(\x0b\x32\x33.oak9.tython.aws.fsx.FileSystemWindowsConfiguration\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\x03\x46Sx\x12\x34\n\x0b\x66ile_system\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.fsx.FileSystemb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_fsx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILESYSTEM_TAGSENTRY._options = None
  _FILESYSTEM_TAGSENTRY._serialized_options = b'8\001'
  _FILESYSTEMLUSTRECONFIGURATION._serialized_start=64
  _FILESYSTEMLUSTRECONFIGURATION._serialized_end=497
  _FILESYSTEMSELFMANAGEDACTIVEDIRECTORYCONFIGURATION._serialized_start=500
  _FILESYSTEMSELFMANAGEDACTIVEDIRECTORYCONFIGURATION._serialized_end=773
  _FILESYSTEMWINDOWSCONFIGURATION._serialized_start=776
  _FILESYSTEMWINDOWSCONFIGURATION._serialized_end=1255
  _FILESYSTEM._serialized_start=1258
  _FILESYSTEM._serialized_end=1756
  _FILESYSTEM_TAGSENTRY._serialized_start=1713
  _FILESYSTEM_TAGSENTRY._serialized_end=1756
  _FSX._serialized_start=1758
  _FSX._serialized_end=1817
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.kubeaggregator.pkg.apis.apiregistration.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMkubernetes/kubernetes_io.k8s.kubeaggregator.pkg.apis.apiregistration.v1.proto\x12:oak9.tython.k8s.kubeaggregator.pkg.apis.apiregistration.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xed\x02\n\nAPIService\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12X\n\x04spec\x18\x04 \x01(\x0b\x32J.oak9.tython.k8s.kubeaggregator.pkg.apis.apiregistration.v1.APIServiceSpec\x12\\\n\x06status\x18\x05 \x01(\x0b\x32L.oak9.tython.k8s.kubeaggregator.pkg.apis.apiregistration.v1.APIServiceStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe0\x01\n\x13\x41PIServiceCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8e\x02\n\x0e\x41PIServiceList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12U\n\x05items\x18\x02 \x03(\x0b\x32\x46.oak9.tython.k8s.kubeaggregator.pkg.apis.apiregistration.v1.APIService\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb7\x02\n\x0e\x41PIServiceSpec\x12\x11\n\tca_bundle\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x1e\n\x16group_priority_minimum\x18\x03 \x01(\x05\x12 \n\x18insecure_skip_tls_verify\x18\x04 \x01(\x08\x12]\n\x07service\x18\x05 \x01(\x0b\x32L.oak9.tython.k8s.kubeaggregator.pkg.apis.apiregistration.v1.ServiceReference\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x18\n\x10version_priority\x18\x07 \x01(\x05\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\x10\x41PIServiceStatus\x12\x63\n\nconditions\x18\x01 \x03(\x0b\x32O.oak9.tython.k8s.kubeaggregator.pkg.apis.apiregistration.v1.APIServiceCondition\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"z\n\x10ServiceReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.kubeaggregator.pkg.apis.apiregistration.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APISERVICE._serialized_start=229
  _APISERVICE._serialized_end=594
  _APISERVICECONDITION._serialized_start=597
  _APISERVICECONDITION._serialized_end=821
  _APISERVICELIST._serialized_start=824
  _APISERVICELIST._serialized_end=1094
  _APISERVICESPEC._serialized_start=1097
  _APISERVICESPEC._serialized_end=1408
  _APISERVICESTATUS._serialized_start=1411
  _APISERVICESTATUS._serialized_end=1587
  _SERVICEREFERENCE._serialized_start=1589
  _SERVICEREFERENCE._serialized_end=1711
# @@protoc_insertion_point(module_scope)
